/**
 * Assignment #9: POSIX select() and Socket Connection (Client)
 * Sample Solution
 *
 * Instructor: Ron Mak
 * CMPE 142 Operating Systems
 * Computer Engineering Department
 * San Jose State University
 */
#include <netdb.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/ioctl.h>
#include <arpa/inet.h>
#include <netinet/in.h>
#include "globals.h"

/**
 * Create a socket connection to the server
 * with the given IP address.
 * @param ip_address the IP address.
 * @return the socket file descriptor if no errors, else -1.
 */
int connect_to_socket(char *ip_address)
{
    // Create a socket:
    //   AF_INET: family for IPv4 addresses
    //   SOCK_STREAM: use reliable transport protocol
    //   0: let the kernel decide the default protocol
    int socket_fd = socket(AF_INET, SOCK_STREAM, 0);
    if (socket_fd < 0)
    {
        perror("*** Error: socket()");
        return -1;
    }

    struct sockaddr_in server_address;
    memset(&server_address, '0', sizeof(server_address));

    // Initialize the server address.
    // htons() converts short values from
    // host byte order to network byte order.
    server_address.sin_family = AF_INET;
    server_address.sin_port   = htons(SERVER_PORT);

    // Convert an internet address from text to binary form.
    if (inet_pton(AF_INET, ip_address, &server_address.sin_addr) <= 0)
    {
        perror("*** Error: inet_pton()");
        return -1;
    }

    // Connect the socket to the server address.
    if (connect(socket_fd,
                (struct sockaddr *)&server_address,
                sizeof(server_address)) < 0)
    {
        perror("*** Error: connect()");
        return -1;
    }

    return socket_fd;
}
